@@ -30,9 +30,10 @@ Copyright (C) 2022-2025 by CNRS and University of Strasbourg */
 *
 * List of functions:
 
+  int occupancy (double occ);
   int test_lattice (builder_edition * cbuilder, cell_info * cif_cell);
   int pos_not_saved (vec3_t * all_pos, int num_pos, vec3_t pos);
-  int build_crystal (gboolean visible, project * this_proj, gboolean to_wrap, gboolean show_clones, cell_info * cell, GtkWidget * widg);
+  int build_crystal (gboolean visible, project * this_proj, int c_step, gboolean to_wrap, gboolean show_clones, cell_info * cell, GtkWidget * widg);
 
   double get_val_from_setting (gchar * pos, gchar * sval);
   double get_value_from_pos (gchar * pos);
@@ -41,10 +42,10 @@ Copyright (C) 2022-2025 by CNRS and University of Strasbourg */
   gboolean same_coords (float a, float b);
   gboolean are_equal_vectors (vec3_t u, vec3_t v);
   gboolean pos_not_taken (int pos, int dim, int * tab);
-  gboolean adjust_object_occupancy (crystal_data * cryst, int occupying, int tot_cell);
+  gboolean adjust_object_occupancy (crystal_data * cryst, int occupying, int rouding, int tot_cell);
 
   void get_origin (space_group * spg);
-  void compute_lattice_properties (cell_info * cell);
+  void compute_lattice_properties (cell_info * cell, int box_id);
   void clean_this_proj (project * this_proj, gboolean newp);
 
   space_group * duplicate_space_group (space_group * spg);
@@ -198,16 +199,17 @@ void get_origin (space_group * spg)
 }
 
 /*!
-  \fn void compute_lattice_properties (cell_info * cell)
+  \fn void compute_lattice_properties (cell_info * cell, int box_id)
 
   \brief compute lattice parameters following cell description
 
   \param cell the target cell description
+  \param box_id the target box description to fill
 */
-void compute_lattice_properties (cell_info * cell)
+void compute_lattice_properties (cell_info * cell, int box_id)
 {
   int i;
-  box_info * box = & cell -> box[0];
+  box_info * box = & cell -> box[box_id];
   double ltemp;
   double angle[3];
   double sangle[3], cangle[3];
@@ -354,7 +356,7 @@ int test_lattice (builder_edition * cbuilder, cell_info * cif_cell)
       show_warning ("Please describe properly the lattice parameters", cbuilder -> win);
       return 0;
     }
-    compute_lattice_properties (cell);
+    compute_lattice_properties (cell, 0);
   }
 
   // Strictly different or possibly different ?
@@ -678,7 +680,31 @@ gboolean pos_not_taken (int pos, int dim, int * tab)
 }
 
 /*!
-  \fn gboolean adjust_object_occupancy (crystal_data * cryst, int occupying, int tot_cell)
+  \fn int occupancy (double occ, int cif_occ)
+
+  \brief handle occupancy integer rouding
+
+  \param occ value to round
+  \param cif_occ how to round
+*/
+int occupancy (double occ, int cif_occ)
+{
+  switch (cif_occ)
+  {
+    case 0:
+      return (int)occ;
+      break;
+    case 1:
+      return (int)occ + 1;
+      break;
+    default:
+      return (int)nearbyint(occ);
+      break;
+  }
+}
+
+/*!
+  \fn gboolean adjust_object_occupancy (crystal_data * cryst, int occupying, int rounding, int tot_cell)
 
   \brief adjust the crystallograpĥic sites occupancy
 
@@ -689,9 +715,10 @@ gboolean pos_not_taken (int pos, int dim, int * tab)
       2 = Completely random
       3 = Successively
       4 = Alternatively
+  \param rounding how to round the number of occupied site(s)
   \param tot_cell the total number of cell to build
 */
-gboolean adjust_object_occupancy (crystal_data * cryst, int occupying, int tot_cell)
+gboolean adjust_object_occupancy (crystal_data * cryst, int occupying, int rounding, int tot_cell)
 {
   int h, i, j, k, l, m, n, o, p, q, r, s, t;
   double v;
@@ -774,7 +801,10 @@ gboolean adjust_object_occupancy (crystal_data * cryst, int occupying, int tot_c
 #endif
         if (cryst -> sites[k][0] > -1)
         {
-          num_to_save = round (pos_bs*cryst -> occupancy[k]);
+          // Warning for occupancy closest integer value to:
+          //   - (int) ?
+          //   - nearbyint : closest integer value ?
+          num_to_save = occupancy (pos_bs*cryst -> occupancy[k], rounding);
           l += num_to_save;
 #ifdef DEBUG
           g_debug ("\tnum_to_save= %d, l= %d", num_to_save, l);
@@ -922,24 +952,29 @@ gboolean adjust_object_occupancy (crystal_data * cryst, int occupying, int tot_c
   return low_occ;
 }
 
+gboolean crystal_low_warning;
+gboolean crystal_crowded;
+gboolean crystal_dist_chk;
+
 /*!
-  \fn int build_crystal (gboolean visible, project * this_proj, gboolean to_wrap, gboolean show_clones, cell_info * cell, GtkWidget * widg)
+  \fn int build_crystal (gboolean visible, project * this_proj, int c_step, gboolean to_wrap, gboolean show_clones, cell_info * cell, GtkWidget * widg)
 
   \brief build crystal
 
   \param visible is the crystal builder window visible ?
   \param this_proj the target project
+  \param c_step the MD step if multiple CIF configurations
   \param to_wrap wrap or not atomic coordinates in the unit cell
   \param show_clones show / hide clone(s)
   \param cell the cell info that contains the crystal description
   \param widg the GtkWidget sending the signal
 */
-int build_crystal (gboolean visible, project * this_proj, gboolean to_wrap, gboolean show_clones, cell_info * cell, GtkWidget * widg)
+int build_crystal (gboolean visible, project * this_proj, int c_step, gboolean to_wrap, gboolean show_clones, cell_info * cell, GtkWidget * widg)
 {
   int h, i, j, k, l, m, n, o, p, q;
   int build_res = 1;
   space_group * sp_group = cell -> sp_group;
-  box_info * box = & cell -> box[0];
+  box_info * box = & cell -> box[c_step];
   gchar * str;
   mat4_t ** wyckpos = g_malloc0 (sp_group -> numw*sizeof*wyckpos);
   double spgpos[3][4];
@@ -1014,6 +1049,7 @@ int build_crystal (gboolean visible, project * this_proj, gboolean to_wrap, gboo
   gboolean done;
   crystal_data * cdata = NULL;
   int occupying;
+  int rounding;
   double amin = box -> param[0][0];
   for (i=1; i<3; i++) amin = min(amin, box -> param[0][i]);;
   if (! visible)
@@ -1021,7 +1057,7 @@ int build_crystal (gboolean visible, project * this_proj, gboolean to_wrap, gboo
     tint point;
     point.a = this_proj -> id;
     point.b = point.c = 0;
-    this_proj -> modelgl = g_malloc0(sizeof*this_proj -> modelgl);
+    if (! this_proj -> modelgl) this_proj -> modelgl = g_malloc0(sizeof*this_proj -> modelgl);
     prepare_atom_edition (& point, FALSE);
     this_proj -> modelgl -> search_widg[7] = allocate_atom_search (this_proj -> id, INSERT, 7, this_reader -> natomes);
     gboolean do_obj;
@@ -1066,10 +1102,12 @@ int build_crystal (gboolean visible, project * this_proj, gboolean to_wrap, gboo
       for (j=0; j<3; j++) object -> baryc[j] = this_reader -> coord[i][j];
     }
     occupying = 0;
+    rounding = this_reader -> rounding;
   }
   else
   {
     occupying = this_proj -> modelgl -> builder_win -> occupancy;
+    rounding = this_proj -> modelgl -> builder_win -> rounding;
   }
   for (h=0; h<2; h++)
   {
@@ -1165,26 +1203,30 @@ int build_crystal (gboolean visible, project * this_proj, gboolean to_wrap, gboo
         {
           if (object -> dim > amin)
           {
-            str = g_strdup_printf ("%s size (%f Ang.) is bigger than the min(<b><i>a,b,c</i></b>)\n"
-                                   "If you build the crystal the final structure is likely to be crowded !\n"
-                                   "Continue anyway ?", object -> name, object -> dim);
-            build_res = 2;
-            if (! ask_yes_no("This object might be too big !" , str, GTK_MESSAGE_WARNING, widg))
+            if (! crystal_crowded)
             {
-              g_free (str);
-              if (points) g_free (points);
-              if (wyckpos) g_free (wyckpos);
-              if (cdata) cdata = free_crystal_data (cdata);
-              if (! visible)
+              str = g_strdup_printf ("%s size (%f &#xC5;) is bigger than the min(<b><i>a,b,c</i></b>)\n"
+                                     "If you build the crystal the final structure is likely to be crowded !\n"
+                                     "Continue anyway ?", object -> name, object -> dim);
+              build_res = 2;
+              crystal_crowded = ask_yes_no("This object might be too big !" , str, GTK_MESSAGE_WARNING, widg);
+              if (! crystal_crowded)
               {
-                this_proj -> modelgl -> search_widg[7] = free_this_search_data (this_proj -> modelgl -> search_widg[7]);
-                g_free (this_proj -> modelgl);
-                this_proj -> modelgl = NULL;
-                active_glwin = NULL;
+                g_free (str);
+                if (points) g_free (points);
+                if (wyckpos) g_free (wyckpos);
+                if (cdata) cdata = free_crystal_data (cdata);
+                if (! visible)
+                {
+                  this_proj -> modelgl -> search_widg[7] = free_this_search_data (this_proj -> modelgl -> search_widg[7]);
+                  g_free (this_proj -> modelgl);
+                  this_proj -> modelgl = NULL;
+                  active_glwin = NULL;
+                }
+                return 0;
               }
-              return 0;
+              g_free (str);
             }
-            g_free (str);
           }
           i ++;
           j += object -> species;
@@ -1319,12 +1361,13 @@ int build_crystal (gboolean visible, project * this_proj, gboolean to_wrap, gboo
 
   if (new_proj)
   {
-    init_project(TRUE);
+    init_project (TRUE);
   }
   else if (visible)
   {
     active_project_changed (this_proj -> id);
   }
+  active_box = & active_cell -> box[c_step];
   for (i=0; i<3; i++)
   {
     for (j=0; j<3; j++)
@@ -1337,7 +1380,7 @@ int build_crystal (gboolean visible, project * this_proj, gboolean to_wrap, gboo
       active_box -> vect[i][j] *= cell -> cextra[i];
     }
   }
-  compute_lattice_properties (active_cell);
+  compute_lattice_properties (active_cell, c_step);
   active_cell -> ltype = 1;
   active_cell -> pbc = TRUE;
   int tot_cell = 1;
@@ -1409,10 +1452,9 @@ int build_crystal (gboolean visible, project * this_proj, gboolean to_wrap, gboo
     }
   }
   cdata = free_crystal_data (cdata);
-  gboolean low_occ = adjust_object_occupancy (cryst, occupying, tot_cell);
+  gboolean low_occ = adjust_object_occupancy (cryst, occupying, rounding, tot_cell);
   atom at, bt;
   distance dist;
-  gboolean dist_chk = TRUE;
 
   if (! cryst -> overlapping)
   {
@@ -1441,13 +1483,13 @@ int build_crystal (gboolean visible, project * this_proj, gboolean to_wrap, gboo
                   if (dist.length < 0.5)
                   {
                     // g_print ("i= %d, j= %d, k= %d, m= %d, d= %f\n", i, j, k, m, dist.length);
-                    if (dist_chk)
+                    if (crystal_dist_chk)
                     {
                       build_res = 3;
                       if (ask_yes_no ("Inter-object distance(s) < 0.5 Ang. !",
                                       "Inter-object distance(s) &lt; 0.5 Ang. !\n\n\t\tContinue and leave a single object at each position ?", GTK_MESSAGE_WARNING, widg))
                       {
-                        dist_chk = FALSE;
+                        crystal_dist_chk = FALSE;
                       }
                       else
                       {
@@ -1456,7 +1498,7 @@ int build_crystal (gboolean visible, project * this_proj, gboolean to_wrap, gboo
                         return 0;
                       }
                     }
-                    if (! dist_chk)
+                    if (! crystal_dist_chk)
                     {
                       if (dist.length < 0.1)
                       {
@@ -1506,8 +1548,7 @@ int build_crystal (gboolean visible, project * this_proj, gboolean to_wrap, gboo
       }
     }
   }
-  active_project -> steps = 1;
-  active_project -> natomes = tot_new_at;
+
   if (low_occ)
   {
     i = 0;
@@ -1515,16 +1556,35 @@ int build_crystal (gboolean visible, project * this_proj, gboolean to_wrap, gboo
     {
        if (cryst -> nsps[j]) i ++;
     }
-    active_project -> nspec = i;
   }
   else
   {
-    active_project -> nspec = cryst -> spec;
+    i = cryst -> spec;
   }
+  if (! c_step)
+  {
+    active_project -> natomes = tot_new_at;
+    active_project -> nspec = i;
+    alloc_proj_data (active_project, 1);
+  }
+  else
+  {
+    if (active_project -> natomes != tot_new_at)
+    {
 #ifdef DEBUG
-  g_debug ("CRYSTAL:: atoms= %d, species= %d", active_project -> natomes, active_project -> nspec);
+      g_debug ("CRYSTAL:: number of atoms changes between configurations");
 #endif
-  alloc_proj_data (active_project, 1);
+      return -1;
+    }
+    if (active_project -> nspec != i)
+    {
+#ifdef DEBUG
+      g_debug ("CRYSTAL:: number of chemical species changes between configurations");
+#endif
+      return -1;
+    }
+  }
+
   active_project_changed (activep);
   k = l = 0;
   for (i=0; i<cryst -> spec; i++)
@@ -1544,17 +1604,37 @@ int build_crystal (gboolean visible, project * this_proj, gboolean to_wrap, gboo
     else
     {
       j = (int)cryst -> z[i];
-      active_chem -> label[k] = g_strdup_printf ("%s", periodic_table_info[j].lab);
-      active_chem -> element[k] = g_strdup_printf ("%s", periodic_table_info[j].name);
-      active_chem -> nsps[k] = cryst -> nsps[i];
-      active_chem -> chem_prop[CHEM_Z][k] = cryst -> z[i];
-      active_chem -> chem_prop[CHEM_M][k] = set_mass_ (& j);
-      active_chem -> chem_prop[CHEM_R][k] = set_radius_ (& j, & l);
-      active_chem -> chem_prop[CHEM_N][k] = set_neutron_ (& j);
-      active_chem -> chem_prop[CHEM_X][k] = active_chem -> chem_prop[CHEM_Z][k];
+      if (! c_step)
+      {
+        active_chem -> label[k] = g_strdup_printf ("%s", periodic_table_info[j].lab);
+        active_chem -> element[k] = g_strdup_printf ("%s", periodic_table_info[j].name);
+        active_chem -> nsps[k] = cryst -> nsps[i];
+        active_chem -> chem_prop[CHEM_Z][k] = cryst -> z[i];
+        active_chem -> chem_prop[CHEM_M][k] = set_mass_ (& j);
+        active_chem -> chem_prop[CHEM_R][k] = set_radius_ (& j, & l);
+        active_chem -> chem_prop[CHEM_N][k] = set_neutron_ (& j);
+        active_chem -> chem_prop[CHEM_X][k] = active_chem -> chem_prop[CHEM_Z][k];
 #ifdef DEBUG
-      g_debug ("CRYSTAL:: spec= %d, label= %s, nsps= %d", k+1, active_chem -> label[k], active_chem -> nsps[k]);
+        g_debug ("CRYSTAL:: spec= %d, label= %s, nsps= %d", k+1, active_chem -> label[k], active_chem -> nsps[k]);
 #endif
+      }
+      else
+      {
+        if (active_chem -> nsps[k] != cryst -> nsps[i])
+        {
+#ifdef DEBUG
+          g_debug ("CRYSTAL:: number of atoms for chemical species %d changes between configurations", k+1);
+#endif
+          return -1;
+        }
+        if (active_chem -> chem_prop[CHEM_Z][k] != cryst -> z[i])
+        {
+#ifdef DEBUG
+          g_debug ("CRYSTAL:: atomic number for chemical species %d changes between configurations", k+1);
+#endif
+          return -1;
+        }
+      }
       for (m=0; m<tot_new_at;m++)
       {
         if (tot_new_lot[m] == i) tot_new_lot[m] = k;
@@ -1573,18 +1653,18 @@ int build_crystal (gboolean visible, project * this_proj, gboolean to_wrap, gboo
   }
   for (i=0; i<tot_new_at; i++)
   {
-    active_project -> atoms[0][i].id = i;
+    active_project -> atoms[c_step][i].id = i;
     j = tot_new_lot[i];
-    active_project -> atoms[0][i].sp =  j;
-    active_project -> atoms[0][i].x = ncc[i].x + copos[0];
-    active_project -> atoms[0][i].y = ncc[i].y + copos[1];
-    active_project -> atoms[0][i].z = ncc[i].z + copos[2];
-    active_project -> atoms[0][i].show[0] = TRUE;
-    active_project -> atoms[0][i].show[1] = TRUE;
-    active_project -> atoms[0][i].label[0] = FALSE;
-    active_project -> atoms[0][i].label[1] = FALSE;
-    active_project -> atoms[0][i].pick[0] = FALSE;
-    active_project -> atoms[0][i].cloned = FALSE;
+    active_project -> atoms[c_step][i].sp =  j;
+    active_project -> atoms[c_step][i].x = ncc[i].x + copos[0];
+    active_project -> atoms[c_step][i].y = ncc[i].y + copos[1];
+    active_project -> atoms[c_step][i].z = ncc[i].z + copos[2];
+    active_project -> atoms[c_step][i].show[0] = TRUE;
+    active_project -> atoms[c_step][i].show[1] = TRUE;
+    active_project -> atoms[c_step][i].label[0] = FALSE;
+    active_project -> atoms[c_step][i].label[1] = FALSE;
+    active_project -> atoms[c_step][i].pick[0] = FALSE;
+    active_project -> atoms[c_step][i].cloned = FALSE;
 #ifdef DEBUG
     // g_debug ("sp= %d, %s %f %f %f", j+1, active_chem -> label[j], ncc[i].x, ncc[i].y, ncc[i].z);
 #endif
@@ -1617,8 +1697,8 @@ int build_crystal (gboolean visible, project * this_proj, gboolean to_wrap, gboo
       initcwidgets ();
       active_project_changed (activep);
       init_camera (active_project, TRUE);
-      set_img_lights (active_project, active_image);
-      image_init_spec_data (active_image, active_project, active_project -> nspec);
+      setup_default_lights (active_project, active_image);
+      setup_image_spec_data (active_project, active_image);
       glwin_init_spec_data (active_project, active_project -> nspec);
 #ifdef GTK3
       // GTK3 Menu Action To Check
@@ -1655,7 +1735,7 @@ int build_crystal (gboolean visible, project * this_proj, gboolean to_wrap, gboo
       }
     }
     init_camera (active_project, TRUE);
-    active_image -> box_axis[0] = 1;
+    active_image -> abc -> box = 1;
     if (to_wrap)
     {
       shift_it (vec3(0.0,0.0,0.0), 1, activep);
@@ -1688,7 +1768,7 @@ int build_crystal (gboolean visible, project * this_proj, gboolean to_wrap, gboo
   }
   update_insert_combos ();
   active_cell -> sp_group = duplicate_space_group (sp_group);
-  if (low_occ)
+  if (low_occ && crystal_low_warning)
   {
     gchar * low_warning = "The crystal will be created however some objects might be missing,\n"
                            "Occupancy is too low compared to the number of site(s) per cell.\n\n"
@@ -1697,6 +1777,7 @@ int build_crystal (gboolean visible, project * this_proj, gboolean to_wrap, gboo
                           "\t <b>2)</b> Modify the occupancy set-up to 'Completely random'.\n"
                           "\t <b>3)</b> Increase the number of unit cells up to get rid of this message.";
     show_warning (low_warning, widg);
+    crystal_low_warning = FALSE;
   }
   return build_res;
 }
